@@ -18,25 +18,45 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 #
-# $Id$
+# $Id: fetchconfig.pl,v 1.7 2007/07/20 17:05:39 evertonm Exp $
 
 use strict;
 use fetchconfig::Logger;
+use fetchconfig::Constants;
 use fetchconfig::model::Detector;
 
-my $me = `basename $0`;
-chomp $me;
+sub basename {
+    my ($path) = @_;
+
+    my @list;
+
+    if ($^O eq 'MSWin32') {
+	@list = split /\\/, $path;
+    }
+    else {
+	@list = split /\//, $path;
+    }
+
+    pop @list;
+}
+
+my $me = basename($0);
 
 my $log = fetchconfig::Logger->new({ prefix => $me });
 
+$log->info('version ' . fetchconfig::Constants::version);
+
 my @device_file_list;
 
-foreach (@ARGV) {
-    if (/^-devices=(.+)$/) {
+foreach my $opt (@ARGV) {
+    if ($opt eq '-v') {
+	exit; # only show version
+    }
+    if ($opt =~ /^-devices=(.+)$/) {
 	push @device_file_list, $1;
 	next;
     }
-    $log->error("unexpected argument: $_");
+    $log->error("unexpected argument: $opt");
     &usage;
     die;
 }
@@ -49,8 +69,8 @@ if (@device_file_list < 1) {
 
 fetchconfig::model::Detector->init($log);
 
-foreach (@device_file_list) {
-    &load_device_list($_);
+foreach my $dev_file (@device_file_list) {
+    &load_device_list($dev_file);
 }
 
 $log->info("done");
@@ -58,7 +78,7 @@ $log->info("done");
 exit;
 
 sub usage {
-    warn "usage: $me -devices=file\n";
+    warn "usage: $me [-v] -devices=file\n";
 }
 
 sub load_device_list {
